Topology
========

Sage includes some tools for topology, and in particular cell
complexes: (filtered) simplicial complexes, `\Delta`-complexes, cubical
complexes, and simplicial sets.  A class of generic cell complexes is
also available, mainly for developers who want to use it as a base for
other types of cell complexes.

.. toctree::
   :maxdepth: 1

   sage/topology/simplicial_complex
   sage/topology/simplicial_complex_morphism
   sage/topology/simplicial_complex_homset
   sage/topology/simplicial_complex_examples
   sage/topology/delta_complex
   sage/topology/cubical_complex
   sage/topology/simplicial_set
   sage/topology/simplicial_set_constructions
   sage/topology/simplicial_set_examples
   sage/topology/simplicial_set_catalog
   sage/topology/simplicial_set_morphism
   sage/topology/cell_complex
   sage/topology/filtered_simplicial_complex
   sage/topology/moment_angle_complex

.. include:: ../footer.txt
